//bridge-file-version: #0
import { system, Player, world } from "@minecraft/server";
import { config } from "./config";
import { ActionFormData, ModalFormData } from "@minecraft/server-ui";

// 設定フォームの起動
system.afterEvents.scriptEventReceive.subscribe(ev => {
    const { id, sourceEntity } = ev;
    if (sourceEntity?.typeId !== 'minecraft:player') return;

    if (id === 'status:config') {
        new ConfigForm(sourceEntity).selectCategory();
    }
});

class ConfigForm {
    /**
     * Configダイナミックプロパティの読み込み
     */
    static loadConfig() {
        try {
            const behaviorConfig = world.getDynamicProperty("config:behavior");
            const recordingScoreConfig = world.getDynamicProperty("config:recordingScore");

            if (behaviorConfig) {
                config.behavior = JSON.parse(behaviorConfig);
            }
            if (recordingScoreConfig) {
                config.recordingScore = JSON.parse(recordingScoreConfig);
            }
        } catch (error) {
            console.error("設定の読み込み中にエラーが発生しました: ", error);
        }
    }

    /**
     * Configダイナミックプロパティへの書き込み
     */
    static saveConfig() {
        try {
            world.setDynamicProperty("config:behavior", JSON.stringify(config.behavior));
            world.setDynamicProperty("config:recordingScore", JSON.stringify(config.recordingScore));
        } catch (error) {
            console.error("設定の保存中にエラーが発生しました: ", error);
        }
    }

    /**
     * 設定フォーム
     * @param {Player} player 
     */
    constructor(player) {
        this.player = player;
    }

    async selectCategory() {
        const form = new ActionFormData().title('スコアステータス&タグアドオン');
        form.button(config.behavior.description);
        form.button(config.recordingScore.description);

        const { canceled, selection } = await form.show(this.player);
        if (canceled) return;
        if (selection === 0) {
            this.selectBehavior();
        } else {
            this.setRecordingScore();
        }
    }

    async selectBehavior() {
        const form = new ActionFormData().title(config.behavior.description);
        const settings = Object.entries(config.behavior.settings);

        settings.forEach(([key, value]) => {
            form.button(value.description);
        });
        form.button('戻る');

        const { canceled, selection } = await form.show(this.player);
        if (canceled) {
            this.selectCategory();
        } else if (selection === settings.length) {
            this.selectCategory();
        } else {
            this.selectedBehavior = config.behavior.settings[settings[selection][0]];
            this.setTags();
        }
    }

    async setTags() {
        const form = new ModalFormData().title(this.selectedBehavior.description);
        const settings = Object.entries(this.selectedBehavior.settings);

        settings.forEach(([key, value]) => {
            form.toggle(value.description, value.enabled);
        });

        const { canceled, formValues } = await form.show(this.player);
        if (canceled) {
            this.selectBehavior();
        } else {
            settings.forEach(([key, value], index) => {
                this.selectedBehavior.settings[key].enabled = formValues[index];
            });
            ConfigForm.saveConfig();
            this.selectBehavior();
        }
    }

    async setRecordingScore() {
        const form = new ModalFormData().title(config.recordingScore.description);
        const settings = Object.entries(config.recordingScore.settings);

        settings.forEach(([key, value]) => {
            form.toggle(value.description, value.enabled);
        });

        const { canceled, formValues } = await form.show(this.player);
        if (canceled) {
            this.selectCategory();
        } else {
            settings.forEach(([key, value], index) => {
                config.recordingScore.settings[key].enabled = formValues[index];
            });
            ConfigForm.saveConfig();
            this.selectCategory();
        }
    }
}

// Configの初期化処理
const playerSpawnCallback = ev => {
    ConfigForm.loadConfig();
    world.afterEvents.playerSpawn.unsubscribe(playerSpawnCallback);
};
world.afterEvents.playerSpawn.subscribe(playerSpawnCallback);
// reload
/*
if (world.getPlayers()[0]) {
    ConfigForm.loadConfig();
    world.afterEvents.playerSpawn.unsubscribe(playerSpawnCallback);
}
*/